@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -55,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'ゲストのタイムゾーン',
 	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'ログインしていないユーザー（ゲスト、ボット）に表示されるタイムゾーンです。ログインユーザーは ユーザーCP でタイムゾーンを設定できます。',
 	'WARNINGS_EXPIRE'				=> '警告の有効期間',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'この日数が過ぎるとユーザーの記録から警告が自動的に消滅します。消滅した警告は警告数にカウントされません。',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'この日数が過ぎるとユーザーの記録から警告が自動的に消滅します。消滅した警告は警告数にカウントされません。警告を自動的に消滅させたくない場合は 0 を入力してください。',
 ));
 
 // Board Features
@@ -111,7 +109,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> '画像の最大サイズ',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> '高さ x 横幅 を pixel 単位で指定してください',
 	'MAX_FILESIZE'					=> 'ファイルサイズの上限',
-	'MAX_FILESIZE_EXPLAIN'			=> 'アップロードされるアバター画像にのみ適用されます',
+	'MAX_FILESIZE_EXPLAIN'			=> 'アップロードされるアバター画像にのみ適用されます。0 に設定するとファイルサイズの上限はサーバの PHP設定 に依存します。',
 	'MIN_AVATAR_SIZE'				=> '画像の最小サイズ',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> '高さ x 横幅 を pixel 単位で指定してください',
 ));
@@ -178,7 +176,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'リンクの最大数',
 	'MAX_POST_URLS_EXPLAIN'			=> '記事で使用可能なハイパーリンクの数の上限です。0 に設定すると上限はありません。',
 	'MIN_CHAR_LIMIT'				=> '記事/PM １件あたりの最小文字数',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> '記事/PM に最低限書き込む必要のある文字数です',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> '記事/PM に最低限書き込む必要のある文字数です。0 に設定することはできません。',
 	'POSTING'						=> '投稿',
 	'POSTS_PER_PAGE'				=> '１ページあたりの記事表示数',
 	'QUOTE_DEPTH_LIMIT'				=> '引用入れ子の深さ制限',
@@ -241,8 +239,8 @@ $lang = array_merge($lang, array(
 	'USERNAME_ALPHA_ONLY'		=> 'アルファベット、数字のみ',
 	'USERNAME_ALPHA_SPACERS'	=> 'アルファべット、数字、スペーサーのみ',
 	'USERNAME_ASCII'			=> 'ASCII （半角英数字、句読点や記号） のみ',
-	'USERNAME_LETTER_NUM'		=> 'ラテン文字、数字のみ',
-	'USERNAME_LETTER_NUM_SPACERS'	=> 'ラテン文字、数字、スペーサーのみ',
+	'USERNAME_LETTER_NUM'		=> 'ラテン系文字、数字のみ',
+	'USERNAME_LETTER_NUM_SPACERS'	=> 'ラテン系文字、数字、スペーサーのみ',
 	'USERNAME_CHARS'			=> 'ユーザー名として使用可能な文字の制限',
 	'USERNAME_CHARS_ANY'		=> '全ての文字 （数字・記号を含むあらゆる文字）',
 	'USERNAME_CHARS_EXPLAIN'	=> 'ユーザー名として使用可能な文字を制限してください。スペーサーとは半角スペースと記号 -+_[] の事です。',
@@ -253,7 +251,7 @@ $lang = array_merge($lang, array(
 // Feeds
 $lang = array_merge($lang, array(
 	'ACP_FEED_MANAGEMENT'				=> 'フィード設定',
-	'ACP_FEED_MANAGEMENT_EXPLAIN'		=> 'ここではフィードの設定を行うことができます。<br /><br /><em>フィード （ Feed ） とは XML形式による更新情報の配信、または 配信された情報 のことです。サイトから配信されたフィードを受け取ることによって、サイト利用者はサイトの更新履歴を確認できるようになります。これによってサイト利用者は更新ページにダイレクトでアクセスできるので、情報取得にかかる時間を大幅に減らせたり、重要な情報を見落したりすることが少なくなります。</em><br /><br />phpBB3 ではフィードフォーマットとして ATOMフィード を利用します： BBCode やスマイリーはフィードリーダーできちんとパースされて表示されます。',
+	'ACP_FEED_MANAGEMENT_EXPLAIN'		=> 'ここではフィードの設定を行うことができます。<br /><br /><em>フィード (Feed) とは XML形式による更新情報の配信、または 配信された情報 のことです。サイトから配信されたフィードを受け取ることによって、サイト利用者はサイトの更新履歴を確認できるようになります。これによってサイト利用者は更新ページにダイレクトでアクセスできるので、情報取得にかかる時間を大幅に減らせたり、重要な情報を見落したりすることが少なくなります。</em><br /><br />phpBB3 ではフィードフォーマットとして ATOMフィード を利用します： BBCode やスマイリーはフィードリーダーできちんとパースされて表示されます。',
 
 	'ACP_FEED_GENERAL'					=> '一般設定',
 	'ACP_FEED_POST_BASED'				=> '記事のフィード設定',
@@ -392,7 +390,7 @@ $lang = array_merge($lang, array(
 	'APACHE_SETUP_BEFORE_USE'	=> 'apache 認証を使用するには先に apache 認証をセットアップする必要があります。apache 認証で使用するユーザー名と phpBB で使用するユーザー名は一致している必要があります。apache 認証は mod_php（CGI バージョンは不可） と safe_mode が無効の時に限り使用可能です。',
 
 	'LDAP_DN'						=> 'LDAP ベース <var>dn</var>',
-	'LDAP_DN_EXPLAIN'				=> 'dn は Distinguished Name（識別名） の略です。dn はユーザー情報を識別します。例 o=My Company, c=US',
+	'LDAP_DN_EXPLAIN'				=> 'dn は Distinguished Name （識別名） の略です。dn はユーザー情報を識別します。例. o=My Company, c=US',
 	'LDAP_EMAIL'					=> 'LDAP メールアドレス',
 	'LDAP_EMAIL_EXPLAIN'			=> '新規ユーザーの LDAP メールアドレスをあなたの LDAP メールアドレスを使って自動登録するため、あなたのユーザーエントリ情報にもしメールアドレスがあればそちらを入力してください。',
 	'LDAP_INCORRECT_USER_PASSWORD'	=> '入力した ユーザー名/パスワード を用いて LDAPサーバ へ接続を試みましたが失敗しました',
@@ -433,7 +431,7 @@ $lang = array_merge($lang, array(
 	'SERVER_PORT'				=> 'サーバポート番号',
 	'SERVER_PORT_EXPLAIN'		=> 'サーバが使用するポート番号です。多くの場合、ポート番号は 80 です。もし違う場合は変更してください。',
 	'SERVER_PROTOCOL'			=> 'サーバプロトコル',
-	'SERVER_PROTOCOL_EXPLAIN'	=> '“サーバ設定 と URL設定 の強制” を “はい” にしている場合、このプロトコルが強制使用されます。もし空白か “いいえ” にしている場合、cookie セキュア設定に基づいてプロトコルが使用されます( <samp>http://</samp> または <samp>https://</samp> )。',
+	'SERVER_PROTOCOL_EXPLAIN'	=> '“サーバ設定 と URL設定 の強制” を “はい” にしている場合、このプロトコルが強制使用されます。もし空白か “いいえ” にしている場合、cookie セキュア設定に基づいてプロトコルが使用されます(<samp>http://</samp> または <samp>https://</samp>)。',
 	'SERVER_URL_SETTINGS'		=> 'サーバ設定 と URL設定',
 	'SMILIES_PATH'				=> 'スマイリー画像の格納パス',
 	'SMILIES_PATH_EXPLAIN'		=> 'phpBB ルートディレクトリから見た相対パスで指定する必要があります。例: <samp>images/smilies</samp>',
