@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -293,9 +291,9 @@ $lang = array_merge($lang, array(
 
 // PHP info
 $lang = array_merge($lang, array(
-	'ACP_PHP_INFO_EXPLAIN'	=> 'ここではサーバにインストールされている PHP の設定情報 （ php.ini ） を確認できます。設定情報には拡張モジュール、利用可能な変数、デフォルト設定の詳細が含まれています。これらの情報はサイトに何か問題が起こった場合、その問題を診断する時に役立つはずです。ホスティングサービスを利用している場合、サーバ運営会社によってはセキュリティ上の理由で表示される情報が制限されている可能性があります。www.phpbb.com のサポートフォーラムの<a href="http://www.phpbb.com/about/team/">オフィシャルチームメンバー</a>に質問する時以外はこのページにおけるいかなる情報も口外すべきではない事を忠告しておきます。',
+	'ACP_PHP_INFO_EXPLAIN'	=> 'ここではサーバにインストールされている PHP の設定情報 (php.ini) を確認できます。設定情報には拡張モジュール、利用可能な変数、デフォルト設定の詳細が含まれています。これらの情報はサイトに何か問題が起こった場合、その問題を診断する時に役立つはずです。ホスティングサービスを利用している場合、サーバ運営会社によってはセキュリティ上の理由で表示される情報が制限されている可能性があります。www.phpbb.com のサポートフォーラムの<a href="http://www.phpbb.com/about/team/">オフィシャルチームメンバー</a>に質問する時以外はこのページにおけるいかなる情報も口外すべきではない事を忠告しておきます。',
 
-	'NO_PHPINFO_AVAILABLE'	=> 'PHP設定情報 （ php.ini ） を取得できません。セキュリティ上の理由で phpinfo() が使えなくなっています。',
+	'NO_PHPINFO_AVAILABLE'	=> 'PHP設定情報 (php.ini) を取得できません。セキュリティ上の理由で phpinfo() が使えなくなっています。',
 ));
 
 // Logs
@@ -317,9 +315,9 @@ $lang = array_merge($lang, array(
 
 // Index page
 $lang = array_merge($lang, array(
-	'ADMIN_INTRO'				=> 'Administration Control Panel ( AdminCP ) へようこそ。AdminCP では掲示板を管理するための様々な機能を利用できます。',
+	'ADMIN_INTRO'				=> 'Administration Control Panel (AdminCP) へようこそ。AdminCP では掲示板を管理するための様々な機能を利用できます。',
 	'ADMIN_LOG'					=> 'Admin ログ',
-	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'Admin によって実行された最近５件のアクションです。全ログを確認するには次のリンクをクリックしてください。',
+	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'Admin によって実行された最近５件のアクションです。全ログを確認するには Adminログページ へ移動してください。',
 	'AVATAR_DIR_SIZE'			=> 'アバターディレクトリのサイズ',
 
 	'BOARD_STARTED'		=> '掲示板開始日時',
@@ -392,21 +390,21 @@ $lang = array_merge($lang, array(
 	'VIEW_INACTIVE_USERS'	=> '無効アカウント ページへ',
 
 	'WELCOME_PHPBB'			=> 'phpBB へようこそ',
-	'WRITABLE_CONFIG'		=> 'コンフィグファイル ( config.php ) のアクセス権の設定が非常に危険です。サーバの全ユーザーに対して書き込みが許可されており、誰でも修正できる状態にあります。今すぐにファイルアクセス権を 640 または少なくとも 644 に設定 （ <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php ） してください。',
+	'WRITABLE_CONFIG'		=> 'コンフィグファイル (config.php) のアクセス権の設定が非常に危険です。サーバの全ユーザーに対して書き込みが許可されており、誰でも修正できる状態にあります。今すぐにファイルアクセス権を 640 または少なくとも 644 に設定 (<a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php) してください。',
 ));
 
 // Inactive Users
 $lang = array_merge($lang, array(
 	'INACTIVE_DATE'					=> 'アカウント無効化日時',
 	'INACTIVE_REASON'				=> '無効理由',
-	'INACTIVE_REASON_MANUAL'		=> 'Admin がアカウントを無効化した',
-	'INACTIVE_REASON_PROFILE'		=> 'プロフィールの詳細を変更した',
-	'INACTIVE_REASON_REGISTER'		=> '新しくアカウントを登録した',
-	'INACTIVE_REASON_REMIND'		=> 'ユーザーにアカウント有効化メールを再送信した',
+	'INACTIVE_REASON_MANUAL'		=> 'Admin がアカウントを無効化したため',
+	'INACTIVE_REASON_PROFILE'		=> 'Admin がカスタムプロフィールフィールド設定を変更したため',
+	'INACTIVE_REASON_REGISTER'		=> '新規アカウントのため',
+	'INACTIVE_REASON_REMIND'		=> 'Admin がアカウントの再有効化を要求したため',
 	'INACTIVE_REASON_UNKNOWN'		=> '不明',
 	'INACTIVE_USERS'				=> '無効アカウント',
-	'INACTIVE_USERS_EXPLAIN'		=> 'アカウントが無効（停止）状態の登録ユーザーのリストです。無効アカウントに対して、有効化、削除、アカウント有効化メールの送信を行うことができます。',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'アカウントが無効（停止）状態の登録ユーザーの最近１０件のリストです。全ての無効アカウントを確認するには次のリンクをクリックしてください。移動先のページでアカウントの有効化、削除、アカウント有効化メールの送信を行うことができます。',
+	'INACTIVE_USERS_EXPLAIN'		=> 'アカウントが無効（停止）状態の登録ユーザーのリストです。無効アカウントに対して、有効化、削除、アカウント有効化メールの送信 を行うことができます。',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'アカウントが無効（停止）状態の登録ユーザーの最近１０件のリストです。全ての無効アカウントを確認するには 無効アカウントページ へ移動してください。ユーザー登録設定ページのアクティベーション設定によっては無効アカウントが発生しない状況もあります。アカウントの有効化、削除、アカウント有効化メールの送信 を行うことができます。',
 
 	'NO_INACTIVE_USERS'	=> '無効アカウントはありません',
 
@@ -716,7 +714,7 @@ $lang = array_merge($lang, array(
 	'LOG_USER_INACTIVE'		=> '<strong>アカウントを無効化しました</strong><br />≫ %s',
 	'LOG_USER_MOVE_POSTS'	=> '<strong>記事を移動しました</strong><br />≫ posts by “%1$s” to forum “%2$s” ',
 	'LOG_USER_NEW_PASSWORD'	=> '<strong>パスワードを変更しました</strong><br />≫ %s',
-	'LOG_USER_REACTIVATE'	=> '<strong>アカウント有効化メールを送信しました</strong><br />≫ %s',
+	'LOG_USER_REACTIVATE'	=> '<strong>アカウントの再有効化を要求しました</strong><br />≫ %s',
 	'LOG_USER_REMOVED_NR'	=> '<strong>ユーザーを一見さんから登録ユーザーに変更しました</strong><br />» %s',
 
 	'LOG_USER_UPDATE_EMAIL'	=> '<strong>ユーザー “%1$s” がメールアドレスを変更しました</strong><br />≫ from “%2$s” to “%3$s” ',
@@ -731,7 +729,7 @@ $lang = array_merge($lang, array(
 	'LOG_USER_INACTIVE_USER'	=> '<strong>アカウントを無効化しました</strong>',
 	'LOG_USER_LOCK'				=> '<strong>自分のトピックを閉鎖しました</strong><br />≫ %s',
 	'LOG_USER_MOVE_POSTS_USER'	=> '<strong>フォーラムの全記事を移動しました</strong>≫ %s',
-	'LOG_USER_REACTIVATE_USER'	=> '<strong>アカウント有効化メールを送信しました</strong>',
+	'LOG_USER_REACTIVATE_USER'	=> '<strong>アカウントの再有効化を要求しました</strong>',
 	'LOG_USER_UNLOCK'			=> '<strong>自分のトピックを開放しました</strong><br />≫ %s',
 	'LOG_USER_WARNING'			=> '<strong>警告しました</strong><br />≫ %s',
 	'LOG_USER_WARNING_BODY'		=> '<strong>警告しました</strong><br />≫ %s',
