@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -98,9 +96,9 @@ $lang = array_merge($lang, array(
 	'ACP_VIEW_FORUM_MOD_PERMISSIONS_EXPLAIN'	=> 'ここでは各フォーラムでユーザーまたはグループに与えられているモデレータパーミッションを閲覧・確認できます。',
 	'ACP_VIEW_USER_PERMISSIONS_EXPLAIN'			=> 'ここではユーザーまたはグループに与えられているユーザーパーミッションを閲覧・確認できます。',
 
-	'ADD_GROUPS'				=> 'グループ追加',
-	'ADD_PERMISSIONS'			=> 'パーミッション追加',
-	'ADD_USERS'					=> 'ユーザー追加',
+	'ADD_GROUPS'				=> '未設定グループ',
+	'ADD_PERMISSIONS'			=> 'パーミッション付与',
+	'ADD_USERS'					=> 'ユーザー抽出',
 	'ADVANCED_PERMISSIONS'		=> 'カスタム設定',
 	'ALL_GROUPS'				=> '全てのグループを選択',
 	'ALL_NEVER'					=> '全て <samp>NEVER</samp>',
@@ -127,7 +125,7 @@ $lang = array_merge($lang, array(
 	'DELETE_ROLE_CONFIRM'		=> 'パーミッションセットを本当に削除してもよろしいですか？ もし削除しても、このパーミッションセットを与えられているユーザーとグループはパーミッションオプションを<strong>失いません</strong>。',
 	'DISPLAY_ROLE_ITEMS'		=> 'このパーミッションセットを与えられた ユーザー/グループ の閲覧',
 
-	'EDIT_PERMISSIONS'			=> 'パーミッション編集',
+	'EDIT_PERMISSIONS'			=> 'パーミッション変更',
 	'EDIT_ROLE'					=> 'パーミッションセットの編集',
 
 	'GROUPS_NOT_ASSIGNED'		=> 'このパーミッションセットを与えられているグループはありません',
@@ -135,12 +133,12 @@ $lang = array_merge($lang, array(
 	'LOOK_UP_GROUP'				=> 'グループの選択',
 	'LOOK_UP_USER'				=> 'ユーザーの選択',
 
-	'MANAGE_GROUPS'		=> 'グループ管理',
-	'MANAGE_USERS'		=> 'ユーザー管理',
+	'MANAGE_GROUPS'		=> '設定済みグループ',
+	'MANAGE_USERS'		=> '設定済みユーザー',
 
 	'NO_AUTH_SETTING_FOUND'		=> 'パーミッションデータの送信に失敗しました',
 	'NO_ROLE_ASSIGNED'			=> 'パーミッションセットなし',
-	'NO_ROLE_ASSIGNED_EXPLAIN'	=> 'こちらを選択するとカスタム設定になります。未設定にするには “全て<samp>いいえ</samp>” リンクをクリックして更新してください。',
+	'NO_ROLE_ASSIGNED_EXPLAIN'	=> 'こちらを選択するとカスタム設定になります。未設定の状態にしたい場合は “全て <samp>いいえ</samp>” リンクをクリックして更新してください。',
 	'NO_ROLE_AVAILABLE'			=> '使用可能なパーミッションセットがありません',
 	'NO_ROLE_NAME_SPECIFIED'	=> 'パーミッションセットに名前を付けてください',
 	'NO_ROLE_SELECTED'			=> 'パーミッションセットが見つかりません',
@@ -151,7 +149,7 @@ $lang = array_merge($lang, array(
 	'PERMISSION_APPLIED_TO_ALL'		=> 'ユーザー/グループ のチェックボックスをチェックすると、パーミッションオプションまたはパーミッションセットはそれらチェックしたユーザー/グループにも同様に設定されます',
 	'PLUS_SUBFORUMS'				=> '+サブフォーラム',
 
-	'REMOVE_PERMISSIONS'			=> 'パーミッション削除',
+	'REMOVE_PERMISSIONS'			=> 'パーミッション消去',
 	'REMOVE_ROLE'					=> 'パーミッションセットの削除',
  	'RESULTING_PERMISSION'			=> '最終的なパーミッションの値です',
 	'ROLE'							=> 'パーミッションセット',
@@ -173,7 +171,7 @@ $lang = array_merge($lang, array(
 	'ROLE_FORUM_POLLS'			=> 'Standard Access + Polls',
 	'ROLE_FORUM_READONLY'		=> 'Read Only Access',
 	'ROLE_FORUM_STANDARD'		=> 'Standard Access',
-	'ROLE_FORUM_NEW_MEMBER'		=> 'Newly registered User',
+	'ROLE_FORUM_NEW_MEMBER'		=> 'Newly registered User Access',
 	'ROLE_MOD_FULL'				=> 'Full Moderator',
 	'ROLE_MOD_QUEUE'			=> 'Queue Moderator',
 	'ROLE_MOD_SIMPLE'			=> 'Simple Moderator',
@@ -183,7 +181,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOAVATAR'		=> 'No Avatar',
 	'ROLE_USER_NOPM'			=> 'No Private Messages',
 	'ROLE_USER_STANDARD'		=> 'Standard Features',
-	'ROLE_USER_NEW_MEMBER'		=> 'Newly registered User',
+	'ROLE_USER_NEW_MEMBER'		=> 'Newly registered User Features',
 
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'フォーラム管理とフォーラムパーミッション設定へのアクセスが可能です',
 	'ROLE_DESCRIPTION_ADMIN_FULL'			=> '掲示板の全ての管理機能へのアクセスが可能です。<br />一般ユーザーに対して非推奨です。',
@@ -231,7 +229,7 @@ $lang = array_merge($lang, array(
 
 	'TRACE_DEFAULT'					=> 'パーミッションのデフォルトは <samp>いいえ</samp> （未設定） です。以下に続く各グループまたはユーザーのパーミッション設定値次第で暫定値は <samp>はい</samp> か <samp>NEVER</samp> に上書きされます。',
 	'TRACE_FOR'						=> 'トレース',
-	'TRACE_GLOBAL_SETTING'			=> '%s ( グローバル )',
+	'TRACE_GLOBAL_SETTING'			=> '%s (グローバル)',
 	'TRACE_GROUP_NEVER_TOTAL_NEVER'			=> '<samp>NEVER</samp> に設定されています。直前も <samp>NEVER</samp> なので <samp>NEVER</samp> が保持されます。',
  	'TRACE_GROUP_NEVER_TOTAL_NEVER_LOCAL'	=> '<samp>NEVER</samp> に設定されています。直前も <samp>NEVER</samp> なので <samp>NEVER</samp> が保持されます。',
 	'TRACE_GROUP_NEVER_TOTAL_NO'			=> '<samp>NEVER</samp> に設定されています。暫定値がまだ設定されていないのでこの値が新しい暫定値となります。',
@@ -284,7 +282,7 @@ $lang = array_merge($lang, array(
 	'VIEW_PERMISSIONS'		=> 'パーミッションの閲覧',
 
 	'WRONG_PERMISSION_TYPE'				=> '不適切なパーミッションタイプが選択されました',
-	'WRONG_PERMISSION_SETTING_FORMAT'	=> '送信されたパーミッション設定データ ( $_POST[\'setting\'] ) に不備があるため、パーミッション設定を正常に行えませんでした',
+	'WRONG_PERMISSION_SETTING_FORMAT'	=> '送信されたパーミッション設定データ ($_POST[\'setting\']) に不備があるため、パーミッション設定を正常に行えませんでした',
 ));
 
 ?>
\ No newline at end of file
