@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -73,14 +71,14 @@ $lang = array_merge($lang, array(
 
 	'TOKEN'					=> 'トークン',
 	'TOKENS'				=> 'トークンとは',
-	'TOKENS_EXPLAIN'		=> 'トークン ( token ) の概念を一言で表現すればそれは “抽象化された代替物” です。<br /><em>トークン ( token ) の概念を例を用いて具体的に説明しましょう。明治時代初期、政府が誕生してからまだ日が浅かった為に日本で円は流通していませんでした。その当時の人々の経済はおそらく物々交換経済か、あるいは貨幣としてお米か金 （きん） を使用していたはずです。当時は治安が悪かったので、人々は安全の為により信用のおける資産家の蔵に自分のお米や金を預け（貸し）たいと考えたでしょう。お米か金を預かった資産家は借りた相手に当然 “借用書” を渡します。その “借用書” がトークンです。その借用書をその資産家に持って行きさえすればいつでもお米か金に交換する事ができたので、お米か金をその場で持っていなくても人々はその借用書で物を買ったり売ったりする事ができました。実際には借用書自体はただの紙切れに過ぎないにもかかわらず、その紙切れがまさにお米か金そのものであるかのように振舞っています。すなわち、“借用書という紙切れ” ＝ “お米や金の代替物” ＝ “お米や金のトークン” という事です。</em><br /><br />トークンとして使用可能な型は数値だけでなく、文字列（テキスト、メールアドレス、URL、HTMLカラー等）も使用できます。当然、文章作成の際に BBCode に入力する型とそれに対応するトークンの型は一致している必要があります。同じトークンを複数使用する場合は {TEXT1}, {TEXT2} のようにトークン名の後ろに数値を付け足してください。<br /><br />BBCode を作成する際、language/ja ディレクトリ内の各ファイルで定義されている言語キーを {L_<em>&lt;STRINGNAME&gt;</em>} の形で使用する事ができます。例えば、トークン {L_WROTE} は “さんが書きました” に置換されます。',
+	'TOKENS_EXPLAIN'		=> 'トークン (token) の概念を一言で表現すればそれは “抽象化された代替物” です。<br /><em>トークン (token) の概念を例を用いて具体的に説明しましょう。明治時代初期、政府が誕生してからまだ日が浅かった為に日本で円は流通していませんでした。その当時の人々の経済はおそらく物々交換経済か、あるいは貨幣としてお米か金 （きん） を使用していたはずです。当時は治安が悪かったので、人々は安全の為により信用のおける資産家の蔵に自分のお米や金を預け（貸し）たいと考えたでしょう。お米か金を預かった資産家は借りた相手に当然 “借用書” を渡します。その “借用書” がトークンです。その借用書をその資産家に持って行きさえすればいつでもお米か金に交換する事ができたので、お米か金をその場で持っていなくても人々はその借用書で物を買ったり売ったりする事ができました。実際には借用書自体はただの紙切れに過ぎないにもかかわらず、その紙切れがまさにお米か金そのものであるかのように振舞っています。すなわち、“借用書という紙切れ” ＝ “お米や金の代替物” ＝ “お米や金のトークン” という事です。</em><br /><br />トークンとして使用可能な型は数値だけでなく、文字列（テキスト、メールアドレス、URL、HTMLカラー等）も使用できます。当然、文章作成の際に BBCode に入力する型とそれに対応するトークンの型は一致している必要があります。同じトークンを複数使用する場合は {TEXT1}, {TEXT2} のようにトークン名の後ろに数値を付け足してください。<br /><br />BBCode を作成する際、language/ja ディレクトリ内の各ファイルで定義されている言語キーを {L_<em>&lt;STRINGNAME&gt;</em>} の形で使用する事ができます。例えば、トークン {L_WROTE} は “さんが書きました” に置換されます。',
 	'TOKEN_DEFINITION'		=> '何のトークンか？',
 	'TOO_MANY_BBCODES'		=> 'BBCode をこれ以上作成できません。BBCode を１つ以上削除してからもう一度作成してください。',
 
 	'tokens'	=>	array(
 		'TEXT'			=> 'テキスト文字（漢字、ひらがな、特殊記号等を含むあらゆる文字）。HTMLタグ 内でこのトークンを使用すべきではありません。HTMLタグ 内でトークンを使用する場合は IDENTIFIER または INTTEXT または SIMPLETEXT を使用してください。',
 		'SIMPLETEXT'	=> '半角アルファベット(A-Z)、半角数字(0-9)、半角スペース、コンマ(,)、マイナス(-)、プラス(+)、ハイフン(-)、アンダーライン(_)',
-		'INTTEXT'		=> 'ラテン文字、半角数字(0-9)、半角スペース、コンマ(,)、マイナス(-)、プラス(+)、ハイフン(-)、アンダーライン(_)、ドット(.)、半角スペース( )',
+		'INTTEXT'		=> 'ラテン系文字、半角数字(0-9)、半角スペース、コンマ(,)、マイナス(-)、プラス(+)、ハイフン(-)、アンダーライン(_)、ドット(.)、半角スペース( )',
 		'IDENTIFIER'	=> '半角アルファベット(A-Z)、半角数字(0-9)、ハイフン(-)、アンダーライン(_)',
 		'NUMBER'		=> '半角数字(0-9)',
 		'EMAIL'			=> 'メールアドレス',
@@ -226,7 +224,7 @@ $lang = array_merge($lang, array(
 	'RANK_ADDED'			=> 'ランクの追加に成功しました',
 	'RANK_IMAGE'			=> 'ランク画像',
 	'RANK_IMAGE_EXPLAIN'	=> 'ランク画像を指定してください。パスは phpBB ルートディレクトリから見た相対パスです。',
-	'RANK_IMAGE_IN_USE'		=> '（ 使用中 ）',
+	'RANK_IMAGE_IN_USE'		=> '(使用中)',
 	'RANK_MINIMUM'			=> '投稿数',
 	'RANK_REMOVED'			=> 'ランクの削除に成功しました',
 	'RANK_SPECIAL'			=> '特別ランクにする',
@@ -252,14 +250,14 @@ $lang = array_merge($lang, array(
 
 // Reasons
 $lang = array_merge($lang, array(
-	'ACP_REASONS_EXPLAIN'	=> 'ここでは理由を管理できます。理由は ユーザーが投稿記事をモデレータに通報する時 と モデレータが記事の承認を却下する時 の選択肢として使用されます。デフォルト理由 （ * でマークされています） は削除できません。デフォルト理由は該当する理由がない場合に使用されます。',
+	'ACP_REASONS_EXPLAIN'	=> 'ここでは理由を管理できます。理由は ユーザーが投稿記事をモデレータに通報する時 と モデレータが記事の承認を却下する時 の選択肢として使用されます。デフォルト理由 (* でマークされています） は削除できません。デフォルト理由は該当する理由がない場合に使用されます。',
 	'ADD_NEW_REASON'		=> '理由の追加',
 	'AVAILABLE_TITLES'		=> 'ローカライズ済みの理由タイトル',
 	
 	'IS_NOT_TRANSLATED'			=> 'ローカライズされて<strong>いません</strong>',
-	'IS_NOT_TRANSLATED_EXPLAIN'	=> 'この理由はローカライズされて<strong>いません</strong>。つまりこの理由のタイトルと説明がそのままユーザーに表示されます。掲示板を利用するユーザーが日本語ユーザーのみなら理由のタイトルと説明が日本語でも問題ありませんが、そうでない場合は言語パック毎にローカライズしたほうが良いでしょう。ローカライズするには言語ファイル ( language/｛言語パック名｝/mcp.php ) に理由を追加してください。具体的には、report_reasons 配列内の各連想配列 TITLE と DESCRIPTION に値を追加する必要があります。',
+	'IS_NOT_TRANSLATED_EXPLAIN'	=> 'この理由はローカライズされて<strong>いません</strong>。つまりこの理由のタイトルと説明がそのままユーザーに表示されます。掲示板を利用するユーザーが日本語ユーザーのみなら理由のタイトルと説明が日本語でも問題ありませんが、そうでない場合は言語パック毎にローカライズしたほうが良いでしょう。ローカライズするには言語ファイル (language/｛言語パック名｝/mcp.php) に理由を追加してください。具体的には、report_reasons 配列内の各連想配列 TITLE と DESCRIPTION に値を追加する必要があります。',
 	'IS_TRANSLATED'				=> 'ローカライズされています',
-	'IS_TRANSLATED_EXPLAIN'		=> 'この理由はローカライズされています。つまり 理由タイトル と 理由の説明 が言語ファイル ( language/ja/mcp.php ) で定義されているため、その定義されたタイトルと説明が使用されます。',
+	'IS_TRANSLATED_EXPLAIN'		=> 'この理由はローカライズされています。つまり 理由タイトル と 理由の説明 が言語ファイル (language/ja/mcp.php) で定義されているため、その定義されたタイトルと説明が使用されます。',
 	
 	'NO_REASON'					=> '理由が見つかりません',
 	'NO_REASON_INFO'			=> '理由タイトルと理由の説明の両方を入力する必要があります',
