@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -71,7 +69,7 @@ $lang = array_merge($lang, array(
 	'DISPLAY_ON_VT'					=> 'トピック表示ページで表示する',
 	'DISPLAY_ON_VT_EXPLAIN'			=> 'トピック表示ページでこのプロフィールフィールドを表示します',
 	'DISPLAY_PROFILE_FIELD'			=> 'プロフィールフィールドを表示する',
-	'DISPLAY_PROFILE_FIELD_EXPLAIN'	=> ' “はい” を選択した場合、このプロフィールフィールドをトピック表示ページ、プロフィールページ、メンバーリストページで表示します。ただし AdminCP の “読み込み設定” で許可されているものに限ります。',
+	'DISPLAY_PROFILE_FIELD_EXPLAIN'	=> ' “はい” を選択した場合、このプロフィールフィールドをトピック表示ページ、プロフィールページ、メンバーリストページで表示します。ただし AdminCP の “読み込み設定” で許可されている場合に限ります。',
  	'DROPDOWN_ENTRIES_EXPLAIN'		=> 'オプションを作成してください。オプション１つにつき１行で入力してください。',
 
 	'EDIT_DROPDOWN_LANG_EXPLAIN'	=> 'オプション名の変更と追加が可能です。新しいオプションを追加する場合は最下行に入力してください。もし既存オプションの間に割り込んで追加してしまうとユーザーのプロフィール情報がそれに合わせて乱れてしまう点にご注意ください。オプションを削除する場合も同様です。もし最下行のオプションを削除した場合、そのオプションを選択している全ユーザーのプロフィールフィールド情報はデフォルト値に設定し直されます。',
@@ -123,7 +121,7 @@ $lang = array_merge($lang, array(
 	'PROFILE_FIELD_ACTIVATED'	=> 'プロフィールフィールドを有効にしました',
 	'PROFILE_FIELD_DEACTIVATED'	=> 'プロフィールフィールドを無効にしました',
 	'PROFILE_LANG_OPTIONS'		=> '言語設定',
-	'PROFILE_TYPE_OPTIONS'		=> 'フィールドタイプ特別設定',
+	'PROFILE_TYPE_OPTIONS'		=> 'フィールドタイプ固有設定',
 
 	'RADIO_BUTTONS'				=> 'ラジオボタン',
 	'REMOVED_PROFILE_FIELD'		=> 'プロフィールフィールドの削除に成功しました',
@@ -133,14 +131,16 @@ $lang = array_merge($lang, array(
 
 	'SAVE'							=> '保存',
 	'SECOND_OPTION'					=> '第２オプション',
+	'SHOW_NOVALUE_FIELD'			=> '未入力・未選択でも表示する',
+	'SHOW_NOVALUE_FIELD_EXPLAIN'	=> 'フィールド未入力または未選択の場合でもプロフィールフィールドを表示します',
 	'STEP_1_EXPLAIN_CREATE'			=> 'ここではプロフィールフィールドの基本パラメータを入力できます。基本パラメータを入力しないと次の設定ページへ進む事はできません。',
 	'STEP_1_EXPLAIN_EDIT'			=> 'ここではプロフィールフィールドの基本パラメータを変更できます。変更をすぐに保存しなくても、次の設定ページへ進めばここで入力された情報は反映されます。',
 	'STEP_1_TITLE_CREATE'			=> 'プロフィールフィールドの作成',
 	'STEP_1_TITLE_EDIT'				=> 'プロフィールフィールドの編集',
-	'STEP_2_EXPLAIN_CREATE'			=> 'ここでは指定されたフィールドタイプについて特別な設定を行うことができます。',
-	'STEP_2_EXPLAIN_EDIT'			=> 'ここでは指定されたフィールドタイプについて特別な設定を行うことができます。<br /><strong>ここでの変更は既に入力・指定されているユーザーのプロフィール設定を変更しない点にご注意ください。</strong>',
-	'STEP_2_TITLE_CREATE'			=> 'フィールドタイプ特別設定',
-	'STEP_2_TITLE_EDIT'				=> 'フィールドタイプ特別設定',
+	'STEP_2_EXPLAIN_CREATE'			=> 'ここでは指定されたフィールドタイプについて、フィールドタイプ固有の設定を行うことができます。',
+	'STEP_2_EXPLAIN_EDIT'			=> 'ここでは指定されたフィールドタイプについて、フィールドタイプ固有の設定を行うことができます。<br /><strong>ここでの変更は既に入力・指定されているユーザーのプロフィール設定に影響しない点にご注意ください。</strong>',
+	'STEP_2_TITLE_CREATE'			=> 'フィールドタイプ固有設定',
+	'STEP_2_TITLE_EDIT'				=> 'フィールドタイプ固有設定',
 	'STEP_3_EXPLAIN_CREATE'			=> '言語パックが複数インストールされているため、デフォルト言語以外の言語についても設定する必要があります。空白にした場合、デフォルト言語の設定がそのまま採用されます。',			
 	'STEP_3_EXPLAIN_EDIT'			=> '言語パックが複数インストールされているため、デフォルト言語以外の言語についても設定する必要があります。空白にした場合、デフォルト言語の設定がそのまま採用されます。',
 	'STEP_3_TITLE_CREATE'			=> 'デフォルト言語以外の言語設定',
