@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -41,10 +39,10 @@ $lang = array_merge($lang, array(
 	'ACP_SEARCH_INDEX_EXPLAIN'				=> 'ここでは検索インデクスを管理できます。サーバの負担を少しでも軽くするため、利用していない検索バックエンドのインデクスは削除すべきです。検索設定を変更しても既に存在しているインデクスは影響を受けません。既存のインデクスに対して新しいインデクス設定ルールを反映するにはインデクスを再構築する必要があります。',
 	'ACP_SEARCH_SETTINGS_EXPLAIN'			=> 'ここでは検索バックエンドを指定できます（検索バックエンドとは記事のインデクス作成と検索処理を行うエンジンの事です）。また、検索処理に制限を課す事によってサーバ負荷を軽くする事もできます。バックエンド共通の設定項目もありますが、バックエンド独自の設定項目もあります。
 	<br /><br />
-	<em>インデクス （ index ） とは索引付けの事であり、具体的には記事が投稿された際に記事の件名と文章中に含まれるキーワードを抜き出してデータベースに保管する事を意味します。検索処理はデータベースに保管されたこのインデクス情報を基にして行われます。 phpBB3 では検索バックエンドは Fulltext mysql と Fulltext native がはじめから用意されており、ここでどちらを利用するかを選択できます。初期設定では Fulltext native が選択されています。 Fulltext mysql を使用するにはデータベースが MySQL である必要があります。</em>',
+	<em>インデクス (index) とは索引付けの事であり、具体的には記事が投稿された際に記事の件名と文章中に含まれるキーワードを抜き出してデータベースに保管する事を意味します。検索処理はデータベースに保管されたこのインデクス情報を基にして行われます。 phpBB3 では検索バックエンドは Fulltext mysql と Fulltext native がはじめから用意されており、ここでどちらを利用するかを選択できます。初期設定では Fulltext native が選択されています。 Fulltext mysql を使用するにはデータベースが MySQL である必要があります。</em>',
 
 	'COMMON_WORD_THRESHOLD'					=> 'コモンワード判定レベル',
-	'COMMON_WORD_THRESHOLD_EXPLAIN'			=> 'ある検索キーワードが全体の記事数に対してこのパーセンテージ （％） 以上の記事数をヒットする場合、その検索キーワードは コモンワード ( common word ) とみなされ検索処理されません。コモンワードは検索クエリ （データベースへの問い合わせ） の際に無視されます。この機能が働くのは記事数が １００ を超えている場合のみです。もしこの機能を無効化したい場合は 0 を入力してください。コモンワード判定レベルを変更した場合、新しいコモンワード判定レベルを過去に投稿された記事に対して適用するにはインデクスを再構築する必要があります。',
+	'COMMON_WORD_THRESHOLD_EXPLAIN'			=> 'ある検索キーワードが全体の記事数に対してこのパーセンテージ （％） 以上の記事数をヒットする場合、その検索キーワードは コモンワード (common word) とみなされ検索処理されません。コモンワードは検索クエリ （データベースへの問い合わせ） の際に無視されます。この機能が働くのは記事数が １００ を超えている場合のみです。もしこの機能を無効化したい場合は 0 を入力してください。コモンワード判定レベルを変更した場合、新しいコモンワード判定レベルを過去に投稿された記事に対して適用するにはインデクスを再構築する必要があります。',
 	'CONFIRM_SEARCH_BACKEND'				=> '検索バックエンドを本当に変更してもよろしいですか？ 検索バックエンドを変更した後は新しい検索バックエンドで検索インデクスを再構築する必要があります。その際、以前の検索バックエンドに戻るつもりがないならサーバ負荷を少しでも軽くするため以前のバックエンドのインデクスは削除しておくべきです。',
 	'CONTINUE_DELETING_INDEX'				=> '継続中のインデクス削除処理を再開する',
 	'CONTINUE_DELETING_INDEX_EXPLAIN'		=> 'インデクス削除中です。“検索インデクス” ページへアクセスするには削除を完了させるかキャンセルする必要があります。',
@@ -59,8 +57,8 @@ $lang = array_merge($lang, array(
 	'FULLTEXT_MYSQL_INCOMPATIBLE_VERSION'	=> 'Fulltext mysql は MySQL4 以上で使用できます',
 	'FULLTEXT_MYSQL_NOT_MYISAM'				=> 'Fulltext mysql を使用するにはデータベースのテーブル形式が MyISAM である必要があります',
 	'FULLTEXT_MYSQL_TOTAL_POSTS'			=> 'インデクス済み記事数',
-	'FULLTEXT_MYSQL_MBSTRING'				=> 'latin 系キャラクタセット以外の UTF-8 文字の使用 （ mbstring によるサポート ） :',
-	'FULLTEXT_MYSQL_PCRE'					=> 'latin 系キャラクタセット以外の UTF-8 文字の使用 （ PCRE によるサポート ） :',
+	'FULLTEXT_MYSQL_MBSTRING'				=> 'latin 系キャラクタセット以外の UTF-8 文字の使用 (mbstring によるサポート) :',
+	'FULLTEXT_MYSQL_PCRE'					=> 'latin 系キャラクタセット以外の UTF-8 文字の使用 (PCRE によるサポート) :',
 	'FULLTEXT_MYSQL_MBSTRING_EXPLAIN'		=> 'もし PCRE（Perl互換正規表現） 関数 preg_match が Unicodeプロパティ \p{Prop} を取り扱えない場合、latin 系キャラクタセット以外の UTF-8 文字（かな漢字）を検索する際、検索バックエンドは PHP拡張モジュール mbstring の正規表現関数 mb_ereg の使用を試みます',
 	'FULLTEXT_MYSQL_PCRE_EXPLAIN'			=> 'この検索バックエンドを使用するに当たって、latin 系キャラクタセット以外の UTF-8 文字（かな漢字）を検索するには、PCRE（Perl互換正規表現） 関数 preg_match が Unicodeプロパティ \p{Prop} を取り扱える必要があります。PHP は 4.4 か 5.1 以上である必要があります。',
 	'FULLTEXT_MYSQL_MIN_SEARCH_CHARS_EXPLAIN'	=> 'この数より小さい字数のキーワードはインデクスの対象となりません。	この設定を変更するには MySQL のコンフィグ設定を変更する必要があります。',
