@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -104,7 +102,7 @@ $lang = array_merge($lang, array(
 	'EDIT_THEME'						=> 'テーマの編集',
 	'EDIT_THEME_EXPLAIN'				=> 'ここではテーマ （CSS） の編集を行うことができます',
 	'EDIT_THEME_STORED_DB'				=> 'CSSファイル に対するアクセス権 （書き込み） が無かったため、CSSコード をデータベースに格納しました',
- 	'EDIT_THEME_STORE_PARSED'			=> 'このテーマは CSSファイル 内にテンプレート変数 （ {T_IMAGESET_PATH} 等 ） を含んでいるため、ファイルシステムで運用できません',
+ 	'EDIT_THEME_STORE_PARSED'			=> 'このテーマは CSSファイル 内にテンプレート変数 ({T_IMAGESET_PATH} 等) を含んでいるため、ファイルシステムで運用できません',
 	'EDITOR_DISABLED'					=> 'テンプレートエディタの使用は無効化されています',
 	'EXPORT'							=> 'エクスポート',
 
@@ -170,7 +168,7 @@ $lang = array_merge($lang, array(
 	'IMG_FORUM_UNREAD_LOCKED'	=> '未読-閉鎖中フォーラム',
 	'IMG_FORUM_UNREAD_SUBFORUM'	=> '未読-親フォーラム',
 	'IMG_SUBFORUM_READ'			=> 'サブフォーラム （フォーラム説明の下で表示）',
-	'IMG_SUBFORUM_UNREAD'		=> '未読サブフォーラム （フォーラム説明の下で表示 ）',
+	'IMG_SUBFORUM_UNREAD'		=> '未読サブフォーラム （フォーラム説明の下で表示)',
 
 	'IMG_TOPIC_MOVED'			=> '移動済みトピック',
 
@@ -268,6 +266,7 @@ $lang = array_merge($lang, array(
 	'IMG_USER_ICON9'		=> '追加画像 9',
 	'IMG_USER_ICON10'		=> '追加画像 10',
 
+	'INACTIVE_STYLES'			=> '無効中のスタイル',
 	'INCLUDE_DIMENSIONS'		=> '画像サイズを指定する',
 	'INCLUDE_IMAGESET'			=> 'イメージセットを含める',
 	'INCLUDE_TEMPLATE'			=> 'テンプレートを含める',
@@ -344,7 +343,7 @@ $lang = array_merge($lang, array(
 	'STORE_DATABASE'			=> 'データベース',
 	'STORE_FILESYSTEM'			=> 'ファイルシステム',
 	'STYLE_ACTIVATE'			=> '有効にする',
-	'STYLE_ACTIVE'				=> 'アクティブ',
+	'STYLE_ACTIVE'				=> '有効にする',
 	'STYLE_ADDED'				=> 'スタイルの追加に成功しました',
 	'STYLE_DEACTIVATE'			=> '無効にする',
 	'STYLE_DEFAULT'				=> 'デフォルトスタイルに指定する',
