@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -61,9 +59,9 @@ $lang = array_merge($lang, array(
 
 	'DELETE_POSTS'			=> '全投稿記事の削除',
 	'DELETE_USER'			=> 'アカウントの削除',
-	'DELETE_USER_EXPLAIN'	=> '一度ユーザーを削除してしまうと元には戻せませんのでご注意ください',
+	'DELETE_USER_EXPLAIN'	=> '一度ユーザーを削除してしまうと元には戻せませんのでご注意ください。このユーザーが送信したプライベートメッセージは受信者が未読の場合に限り削除されます。',
 
-	'FORCE_REACTIVATION_SUCCESS'	=> 'アカウントの有効化に成功しました',
+	'FORCE_REACTIVATION_SUCCESS'	=> 'アカウント再有効化メールをユーザーに送信しました',
 	'FOUNDER'						=> 'ウェブマスター',
 	'FOUNDER_EXPLAIN'				=> 'ウェブマスター（原文:Founder) は全ての Adminパーミッション を与えられた特別なユーザーです。ウェブマスターをアクセス禁止、アカウント無効化、アカウント削除する事はできません。',
 
@@ -98,7 +96,7 @@ $lang = array_merge($lang, array(
 	'USER_ADMIN_AVATAR_REMOVED'		=> 'ユーザーのアバターの削除に成功しました',
 	'USER_ADMIN_BAN_EMAIL'			=> 'アクセス禁止 [ メールアドレス ]',
 	'USER_ADMIN_BAN_EMAIL_REASON'	=> 'ユーザー管理ページでアクセス禁止 [ メールアドレス ]',
-	'USER_ADMIN_BAN_IP'				=> 'アクセス禁止 （ IPアドレス ）',
+	'USER_ADMIN_BAN_IP'				=> 'アクセス禁止 [ IPアドレス ]',
 	'USER_ADMIN_BAN_IP_REASON'		=> 'ユーザー管理ページでアクセス禁止 [ IPアドレス ]',
 	'USER_ADMIN_BAN_NAME_REASON'	=> 'ユーザー管理ページでアクセス禁止 [ ユーザー名 ]',
 	'USER_ADMIN_BAN_USER'			=> 'アクセス禁止 [ ユーザー名 ]',
@@ -110,7 +108,7 @@ $lang = array_merge($lang, array(
 	'USER_ADMIN_DEL_POSTS'			=> '全投稿記事の削除',
 	'USER_ADMIN_DEL_SIG'			=> 'サインの削除',
 	'USER_ADMIN_EXPLAIN'			=> 'ここではユーザーの様々な情報を管理できます',
-	'USER_ADMIN_FORCE'				=> 'アカウントの有効化',
+	'USER_ADMIN_FORCE'				=> 'アカウントの再有効化をユーザーに要求',
 	'USER_ADMIN_LEAVE_NR'			=> '一見さんから除名',
 	'USER_ADMIN_MOVE_POSTS'			=> '全投稿記事の移動',
 	'USER_ADMIN_SIG_REMOVED'		=> 'ユーザーのサインの削除に成功しました',
@@ -126,6 +124,7 @@ $lang = array_merge($lang, array(
 	'USER_GROUP_SPECIAL'			=> '特別グループ [ メンバー ]',
 	'USER_LIFTED_NR'				=> 'ユーザーを一見さんから除名しました',
 	'USER_NO_ATTACHMENTS'			=> '添付ファイルはありません',
+	'USER_NO_POSTS_TO_DELETE'		=> 'そのユーザーには記事がありません',
 	'USER_OUTBOX_EMPTIED'			=> 'ユーザーの PM 送信ボックス を空にしました',
 	'USER_OUTBOX_EMPTY'				=> 'ユーザーの PM 送信ボックス は既に空です',
 	'USER_OVERVIEW_UPDATED'			=> 'ユーザー情報を更新しました',
