@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-* Translation Contributors: Weby, ELF
 */
 
 /**
@@ -124,7 +122,7 @@ $lang = array_merge($lang, array(
 	'CLOSE_WINDOW'			=> 'ウィンドウを閉じる',
 	'COLOUR_SWATCH'			=> '色のサンプル',
 	'COMMA_SEPARATOR'		=> ', ',	// Used in pagination of ACP & prosilver, use localised comma if appropriate, eg: Ideographic or Arabic
-	'CONFIRM'				=> '確認',
+	'CONFIRM'				=> '変更',
 	'CONFIRM_CODE'			=> 'CAPTCHA 認証コード',
 	'CONFIRM_CODE_EXPLAIN'	         => '表示されたコードを正確に入力してください。各文字は大文字・小文字の区別があります。',
 	'CONFIRM_CODE_WRONG' => '入力した 認証コード が間違っています',
@@ -169,7 +167,7 @@ $lang = array_merge($lang, array(
 	'ENABLED'							=> '有効',
 	'ENCLOSURE'							=> '囲み文字',
 	'ENTER_USERNAME'					=> 'ユーザー名を入力してださい',
-	'ERR_CHANGING_DIRECTORY'			=> 'FTP セッションを開始するに当たってカレントディレクトリをルートディレクトリに変更 （ CHDIR ） しようと試みましたができなかったため、プログラム処理を中断しました',
+	'ERR_CHANGING_DIRECTORY'			=> 'FTP セッションを開始するに当たってカレントディレクトリをルートディレクトリに変更 (CHDIR) しようと試みましたができなかったため、プログラム処理を中断しました',
 	'ERR_CONNECTING_SERVER'				=> 'サーバ接続時にエラーが発生しました',
 	'ERR_JAB_AUTH'						=> 'Jabber サーバ認証に失敗しました',
 	'ERR_JAB_CONNECT'					=> 'Jabber サーバに接続できませんでした',
@@ -453,6 +451,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'				=> '投稿日時',
 	'POST_TOPIC'			=> 'トピックを投稿する',
 	'POST_UNAPPROVED'		=> 'この記事は承認待ちです',
+	'POWERED_BY'			=> 'Powered by %s',
 	'PREVIEW'				=> 'プレビュー',
 	'PREVIOUS'				=> '１つ前へ',		// Used in pagination
 	'PREVIOUS_STEP'			=> '１つ前に戻る',
@@ -462,13 +461,14 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGING'		=> 'プライベートメッセージ',
 	'PROFILE'				=> 'ユーザーCP',
 
+	'RANK'						=> 'ランク',
 	'READING_FORUM'				=> 'フォーラム %s を閲覧中',
 	'READING_GLOBAL_ANNOUNCE'	=> 'グローバル告知トピックを閲覧中',
 	'READING_LINK'				=> 'リンクフォーラム %s を閲覧中',
 	'READING_TOPIC'				=> '%s のトピックを閲覧中',
 	'READ_PROFILE'				=> 'プロフィール',
 	'REASON'					=> '理由',
-	'RECORD_ONLINE_USERS'		=> '最大同時オンラインユーザー数の記録 <strong>%1$s</strong> 人 （ %2$s ）',
+	'RECORD_ONLINE_USERS'		=> '最大同時オンラインユーザー数の記録 <strong>%1$s</strong> 人 (%2$s)',
 	'REDIRECT'					=> 'リダイレクト',
 	'REDIRECTS'					=> 'クリック数',
 	'REGISTER'					=> 'ユーザー登録',
@@ -483,7 +483,7 @@ $lang = array_merge($lang, array(
 	'REG_USER_TOTAL'				=> '登録ユーザー[%d] ',
 	'REG_USER_TOTAL_AND'			=> '登録ユーザー[%d] ',
 	'REMOVE'					=> '削除',
-	'REMOVE_INSTALL'			=> '掲示板を利用できるようにするには install ディレクトリを削除する必要があります。install ディレクトリが存在している間は Administration Control Panel ( AdminCP ) だけしかアクセスできません。',
+	'REMOVE_INSTALL'			=> '掲示板を利用できるようにするには install ディレクトリを削除する必要があります。install ディレクトリが存在している間は Administration Control Panel (AdminCP) だけしかアクセスできません。',
 	'REPLIES'					=> '返信数',
 	'REPLY_WITH_QUOTE'			=> '引用付きで返信する',
 	'REPLYING_GLOBAL_ANNOUNCE'	=> 'グローバル告知トピックに返信中',
@@ -723,7 +723,7 @@ $lang = array_merge($lang, array(
 	'WRONG_DATA_ICQ'			=> '入力した ICQ が正しくありません',
 	'WRONG_DATA_JABBER'			=> '入力した Jabberアカウント名 が正しくありません',
 	'WRONG_DATA_LANG'			=> '指定した 言語 が正しくありません',
-	'WRONG_DATA_WEBSITE'		=> 'ウェブサイトのアドレスはプロトコルまで含めた正しい URL である必要があります（例: http://www.example.com/ ）.',
+	'WRONG_DATA_WEBSITE'		=> 'ウェブサイトのアドレスはプロトコルまで含めた正しい URL である必要があります（例: http://www.example.com/).',
 	'WROTE'						=> 'さんが書きました',
 
 	'YEAR'				=> '年',
@@ -839,16 +839,16 @@ $lang = array_merge($lang, array(
 		'-9.5'	=> '[UTC - 9:30] マルケサス諸島時刻',
 		'-9'	=> '[UTC - 9] アラスカ標準時、ガンビア諸島時刻',
 		'-8'	=> '[UTC - 8] 太平洋標準時',
-		'-7'	=> '[UTC - 7] 山岳部標準時 （ MST ）',
-		'-6'	=> '[UTC - 6] 中央標準時 （ CST ）',
-		'-5'	=> '[UTC - 5] 東部標準時 （ EST ） - 米国・カナダなど',
+		'-7'	=> '[UTC - 7] 山岳部標準時 (MST)',
+		'-6'	=> '[UTC - 6] 中央標準時 (CST)',
+		'-5'	=> '[UTC - 5] 東部標準時 (EST) - 米国・カナダなど',
 		'-4.5'	=> '[UTC - 4:30] ベネズエラ標準時',
-		'-4'	=> '[UTC - 4] 大西洋標準時 （ AST ）',
+		'-4'	=> '[UTC - 4] 大西洋標準時 (AST)',
 		'-3.5'	=> '[UTC - 3:30] カナダ・ニューファンドランド州時刻',
 		'-3'	=> '[UTC - 3] ブラジル・アマゾナス州時刻、中央グリーンランド時刻',
 		'-2'	=> '[UTC - 2] フェルナンド・ド・ノローニャ島時刻、サウスジョージア島＆サウスサンドイッチ諸島時刻',
 		'-1'	=> '[UTC - 1] アゾレス諸島時刻、カーボベルデ共和国時刻、東グリーンランド時刻',
-		'0'		=> '[UTC] 西ヨーロッパ時刻、グリニッジ標準時 （ GMT )',
+		'0'		=> '[UTC] 西ヨーロッパ時刻、グリニッジ標準時 (GMT)',
 		'1'		=> '[UTC + 1] 中央ヨーロッパ標準時、西アフリカ時刻',
 		'2'		=> '[UTC + 2] 東ヨーロッパ時刻、中央アフリカ時刻',
 		'3'		=> '[UTC + 3] モスクワ標準時、東アフリカ時刻',
