@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -42,7 +40,7 @@ $help = array(
 	),
 	array(
 		0 => '登録は必ずしなければいけないの？',
-		1 => '掲示板の管理方針によってはログインしなくても投稿できる場合がありますので必ずしも登録する必要はありません。しかし登録することでユーザー画像の使用、プライベートメッセージ （ PM ） の使用、ユーザーへのメール送信、グループへの参加など様々な機能にアクセスできるようになります。未登録ユーザー （ゲストユーザー） は利用できる機能が登録ユーザーよりも限られます。登録は数分で行うことができますので、掲示板をよく利用する場合はユーザー登録することをお勧めします。'
+		1 => '掲示板の管理方針によってはログインしなくても投稿できる場合がありますので必ずしも登録する必要はありません。しかし登録することでユーザー画像の使用、プライベートメッセージ (PM) の使用、ユーザーへのメール送信、グループへの参加など様々な機能にアクセスできるようになります。未登録ユーザー （ゲストユーザー） は利用できる機能が登録ユーザーよりも限られます。登録は数分で行うことができますので、掲示板をよく利用する場合はユーザー登録することをお勧めします。'
 	),
 	array(
 		0 => 'なぜ自動的にログオフしてしまうの？',
@@ -94,7 +92,7 @@ $help = array(
 	),
 	array(
 		0 => '私の母語が “掲示板の言語” リストにありません！',
-		1 => 'あなたの母語へ翻訳された言語パック （以下 “母語パック” ） が掲示板にインストールされていません。母語パックを掲示板にインストールできるかどうかを管理人に訊いてみてください。もし母語パックがまだ作成されていない場合、ご自分で母語パックを作成して頂いてかまいません。詳細は phpBB Group のウェブサイトをご覧ください （このページの一番下にリンクがあります） 。'
+		1 => 'あなたの母語へ翻訳された言語パック （以下 “母語パック”) が掲示板にインストールされていません。母語パックを掲示板にインストールできるかどうかを管理人に訊いてみてください。もし母語パックがまだ作成されていない場合、ご自分で母語パックを作成して頂いてかまいません。詳細は phpBB Group のウェブサイトをご覧ください （このページの一番下にリンクがあります） 。'
 	),
 	array(
 		0 => 'ユーザー名の下に画像を表示させるには？',
@@ -178,11 +176,11 @@ $help = array(
 	),
 	array(
 		0 => 'スマイリーとは？',
-		1 => 'スマイリー （別称：エモーションアイコン） とは感情を表現するために用いられる小さな画像のことです。例えば、:) は嬉しい感情、:( は悲しい感情を表します。投稿画面でスマイリーの一覧が表示されます。スマイリーが多くなると記事が読みづらくなりますのでスマイリーの乱用はお控えください。スマイリーを乱用した記事はモデレータによる編集・削除・移動の対象となる可能性があります。管理人も投稿の際に使用可能なスマイリーの数を制限するようになるでしょう。'
+		1 => 'スマイリー （別称：エモーションアイコン） とは感情を表現するために用いられる小さな画像のことです。例えば、:) は嬉しい感情、:(は悲しい感情を表します。投稿画面でスマイリーの一覧が表示されます。スマイリーが多くなると記事が読みづらくなりますのでスマイリーの乱用はお控えください。スマイリーを乱用した記事はモデレータによる編集・削除・移動の対象となる可能性があります。管理人も投稿の際に使用可能なスマイリーの数を制限するようになるでしょう。'
 	),
 	array(
 		0 => '記事内に画像を載せることはできますか？',
-		1 => 'できます。もし管理人がファイル添付を許可していれば、あなたは画像をアップロードできます。一方、ファイル添付を許可されていなくても画像ファイルへのハイパーリンクを記事に埋め込むことで画像を表示させることが可能です （例: [img]http://www.example.com/my-picture.gif[/img] ） 。あなたのローカルコンピュータがウェブサーバでない限り、あなたのローカルコンピュータにのみ存在する画像を記事に表示させることはできません。またアクセスにパスワード等が必要なサイト内の画像、Hotmail や Yahoo! のメールボックス内の画像等も利用できない点にご注意ください。画像を表示させるには BBCode [img] をご利用ください。'
+		1 => 'できます。もし管理人がファイル添付を許可していれば、あなたは画像をアップロードできます。一方、ファイル添付を許可されていなくても画像ファイルへのハイパーリンクを記事に埋め込むことで画像を表示させることが可能です （例: [img]http://www.example.com/my-picture.gif[/img]) 。あなたのローカルコンピュータがウェブサーバでない限り、あなたのローカルコンピュータにのみ存在する画像を記事に表示させることはできません。またアクセスにパスワード等が必要なサイト内の画像、Hotmail や Yahoo! のメールボックス内の画像等も利用できない点にご注意ください。画像を表示させるには BBCode [img] をご利用ください。'
 	),
 	array(
 		0 => 'グローバル告知トピックとは？',
@@ -335,7 +333,7 @@ $help = array(
 	),
 	array(
 		0 => '必要な機能がありません',
-		1 => 'このソフトウェアの作成を行ったのは phpBB Group であり著作権は phpBB Group が所有しています。その機能が必要だと思う場合は phpbb.com サイトにて phpBB Group に提案してみてください。新機能の提案・要望は決して phpbb.com の掲示板には書き込まないでください。新機能等の追加の作業は SourceForge で行われています。フォーラムをよく読み、既に提案しようとしている新機能の追加が決まっているかを確認してから新機能の提案・要望の手順を行ってください。'
+		1 => 'このソフトウェアの作成を行ったのは phpBB Group であり著作権は phpBB Group が所有しています。その機能が必要だと思う場合または何らかのバグを報告したい場合、 phpBB Group 運営サイト <a href="http://area51.phpbb.com/">Area51</a> へ訪問してください。詳細はそちらに載せてあります。'
 	),
 	array(
 		0 => 'この掲示板に関連した不正・法的問題については誰に問い合わせればいいのでしょうか？',
