@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -44,6 +42,7 @@ $lang = array_merge($lang, array(
 	'ADD_POLL'					=> '投票の作成',
 	'ADD_POLL_EXPLAIN'			=> '投票トピックにしたくない場合はフィールドを空白のままにしてください',
 	'ALREADY_DELETED'			=> '記事は既に削除されています',
+	'ATTACH_DISK_FULL'			=> 'このファイルを添付するのに必要なディスクスペースがありません',
 	'ATTACH_QUOTA_REACHED'		=> '掲示板の添付ファイル保管スペースが限界に達したため、これ以上ファイルをアップロードすることはできません',
 	'ATTACH_SIG'				=> 'サインを追加する （サインは ユーザーCP で変更できます）',
 
@@ -222,7 +221,7 @@ $lang = array_merge($lang, array(
 	'VIEW_PRIVATE_MESSAGE'		=> '%s送信済みプライベートメッセージを表示する%s',
 
 	'WRONG_FILESIZE'			=> 'ファイルサイズが大き過ぎます。許可されているファイルの最大サイズは %1d %2s です。',
-	'WRONG_SIZE'				=> '画像サイズ （横幅 ｘ 高さ、単位は pix ） を最小 %1$d x %2$d から最大 %3$d x %4$d の間にする必要があります。アップロードされた画像のサイズは %5$d x %6$d です。',
+	'WRONG_SIZE'				=> '画像サイズ （横幅 ｘ 高さ、単位は pix) を最小 %1$d x %2$d から最大 %3$d x %4$d の間にする必要があります。アップロードされた画像のサイズは %5$d x %6$d です。',
 ));
 
 ?>
\ No newline at end of file
