@@ -8,8 +8,6 @@
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
-* Translator: ocean=Yohsuke < n/a > ( n/a ) http://bbmods.info/bbs/
-*
 */
 
 /**
@@ -39,22 +37,22 @@ if (empty($lang) || !is_array($lang))
 
 // Privacy policy and T&C
 $lang = array_merge($lang, array(
-	'TERMS_OF_USE_CONTENT'	=> ' “%1$s” （ 以下 “私達”, “掲示板”, “当サイト”, “%1$s”, “%2$s” ） を利用するに当たって、あなたは以下の規約に同意しているものと見なされます。規約に同意しない場合、 “%1$s” の利用を行わないでください。私達はいつでもこの規約を変更できます。更新・変更された後も “%1$s” を利用している間、あなたは常にこれらの規約に同意しているものと見なされます。<br />
+	'TERMS_OF_USE_CONTENT'	=> ' “%1$s” (以下 “私達”, “掲示板”, “当サイト”, “%1$s”, “%2$s”) を利用するに当たって、あなたは以下の規約に同意しているものと見なされます。規約に同意しない場合、 “%1$s” の利用を行わないでください。私達はいつでもこの規約を変更できます。更新・変更された後も “%1$s” を利用している間、あなたは常にこれらの規約に同意しているものと見なされます。<br />
 	<br />
-	当サイトは phpBB （以下 “phpBBソフトウェア”, “www.phpbb.com”, “phpBB Group”, “phpBB Teams” ） によって構築されています。phpBBソフトウェア は “<a href="http://opensource.org/licenses/gpl-license.php">General Public License</a>” （以下 “GPL” ） 下でリリースされたフォーラムソリューションであり、<a href="http://www.phpbb.com/">www.phpbb.com</a> にてダウンロードできます。phpBBソフトウェア はインターネットでの議論やコミュニケーションをより円滑に行うために phpBB Group によって開発されましたが、phpBB Group は phpBBソフトウェア 上でなされた議論の内容やユーザーの行為には一切責任を負いません。phpBB に関する詳細な情報を知るには <a href="http://www.phpbb.com/">http://www.phpbb.com/</a> をご覧ください。<br />
+	当サイトは phpBB （以下 “phpBBソフトウェア”, “www.phpbb.com”, “phpBB Group”, “phpBB Teams”) によって構築されています。phpBBソフトウェア は “<a href="http://opensource.org/licenses/gpl-license.php">General Public License</a>” （以下 “GPL”) 下でリリースされたフォーラムソリューションであり、<a href="http://www.phpbb.com/">www.phpbb.com</a> にてダウンロードできます。phpBBソフトウェア はインターネットでの議論やコミュニケーションをより円滑に行うために phpBB Group によって開発されましたが、phpBB Group は phpBBソフトウェア 上でなされた議論の内容やユーザーの行為には一切責任を負いません。phpBB に関する詳細な情報を知るには <a href="http://www.phpbb.com/">http://www.phpbb.com/</a> をご覧ください。<br />
 	<br />
 	口汚い記事、猥褻な言葉、品性を欠く記事、他人を中傷する記事、嫌悪感を与える記事、脅迫的な記事、性的差別につながる記事、 “%1$s” のホストサーバが存在する国の法律または国際法に違反する記事、以上を投稿しないことをあなたは同意します。この規約を破った場合、対象ユーザーのアカウント停止が即座に行われます（場合によっては対象ユーザーのプロバイダに報告されます）。この措置を実行するため、全ての投稿記事には投稿者の IPアドレス が記録されます。 “%1$s” は必要と判断すればいつでも掲示板の投稿記事を削除、編集、移動、凍結、閉鎖できることをあなたは同意します。あなたが掲示板で入力した情報はデータベースに保管されることをあなたは同意します。あなたの同意がない限りこの情報は第三者に公開されることはありませんが、ハッキング等によるデータの損傷や盗難があった場合、 “%1$s” と phpBB はその責任を一切負いません。
 	',
 
-	'PRIVACY_POLICY'		=> 'このポリシーは “%1$s” とその関連団体 （以下 “私達”, “掲示板”, “当サイト”, “%1$s”, “%2$s” ） さらには phpBB （以下 “phpBBソフトウェア”, “www.phpbb.com”, “phpBB Group”, “phpBB Teams” ） が、あなたが当サイトへアクセスすることによって発生した情報あるいはあなたが当サイトで入力し送信した情報 （以下 “あなたの情報” ） をどのように利用するかを述べたものです。<br />
+	'PRIVACY_POLICY'		=> 'このポリシーは “%1$s” とその関連団体 （以下 “私達”, “掲示板”, “当サイト”, “%1$s”, “%2$s”) さらには phpBB （以下 “phpBBソフトウェア”, “www.phpbb.com”, “phpBB Group”, “phpBB Teams”) が、あなたが当サイトへアクセスすることによって発生した情報あるいはあなたが当サイトで入力し送信した情報 （以下 “あなたの情報”) をどのように利用するかを述べたものです。<br />
 	<br />
-	あなたの情報は２つの方法で発生します。１つは、 “%1$s” のページを閲覧することによって phpBBソフトウェア が cookie をいくつか作成します。cookie 情報はウェブサーバ上にテキストファイルとして作成され、このファイルは閲覧要求の際にあなたのローカルコンピュータのウェブブラウザにダウンロードされます。作成される cookie の１番目と２番目は ユーザーID （以下 “user-id” ） と 匿名セッションID （以下 “session-id” ） であり、これら ID情報 は phpBBソフトウェア によって自動的にあなたに割り当てられます。作成される cookie の３番目は “%1$s” 内のトピックを閲覧した時に作成されます。この cookie はトピックの既読情報を保管するのに使用され、サイト閲覧の利便性を向上させます。<br />
+	あなたの情報は２つの方法で発生します。１つは、 “%1$s” のページを閲覧することによって phpBBソフトウェア が cookie をいくつか作成します。cookie 情報はウェブサーバ上にテキストファイルとして作成され、このファイルは閲覧要求の際にあなたのローカルコンピュータのウェブブラウザにダウンロードされます。作成される cookie の１番目と２番目は ユーザーID （以下 “user-id”) と 匿名セッションID （以下 “session-id”) であり、これら ID情報 は phpBBソフトウェア によって自動的にあなたに割り当てられます。作成される cookie の３番目は “%1$s” 内のトピックを閲覧した時に作成されます。この cookie はトピックの既読情報を保管するのに使用され、サイト閲覧の利便性を向上させます。<br />
 	<br />
 	“%1$s” には、phpBBソフトウェア 以外のソフトウェア （MODなど） によって動作するページがあるかもしれません。それらの中にはアクセスすることによって cookie を作成するものもあるでしょう。しかしこのドキュメントは phpBBソフトウェア の使用によって発生するあなたの情報の取り扱いについて述べたものであり、他のソフトウェアの使用によって発生するあなたの情報については関知しない点にご注意ください。<br />
 	<br />
-	当サイトへアクセスすることによって発生するあなたの情報の残りもう１つは、あなたが私達に送信するデータです。具体的には、ゲストユーザーとして投稿したデータ （以下 “ゲストの投稿記事”） 、“%1$s” にユーザー登録する際に送信したデータ （以下 “あなたのアカウント情報”） 、登録ユーザーとして投稿したデータ （以下 “あなたの投稿記事” ） です。<br />
+	当サイトへアクセスすることによって発生するあなたの情報の残りもう１つは、あなたが私達に送信するデータです。具体的には、ゲストユーザーとして投稿したデータ （以下 “ゲストの投稿記事”） 、“%1$s” にユーザー登録する際に送信したデータ （以下 “あなたのアカウント情報”） 、登録ユーザーとして投稿したデータ （以下 “あなたの投稿記事”) です。<br />
 	<br />
-	あなたのアカウント情報には一意的に判別できる名前 （以下 “あなたのユーザー名” ） 、ログインに必要なパスワード （以下 “あなたのパスワード” ） 、有効なメールアドレス （以下 “あなたのメールアドレス” ） が含まれています。 “%1$s” におけるこれらあなたの情報は、当サイトのホストサーバが存在する国・地域のデータ保護法によって守られています。ユーザー登録の際に要求される、あなたのユーザー名、パスワード、メールアドレス以外の情報はオプション的なものであり入力しなくてもかまいません。あなたはご自分のアカウント情報のどの情報を公開するかをご自分で選択できます。さらにあなたは phpBBソフトウェア からの自動送信メールについて、許可・不許可を選択できます。<br />
+	あなたのアカウント情報には一意的に判別できる名前 （以下 “あなたのユーザー名”) 、ログインに必要なパスワード （以下 “あなたのパスワード”) 、有効なメールアドレス （以下 “あなたのメールアドレス”) が含まれています。 “%1$s” におけるこれらあなたの情報は、当サイトのホストサーバが存在する国・地域のデータ保護法によって守られています。ユーザー登録の際に要求される、あなたのユーザー名、パスワード、メールアドレス以外の情報はオプション的なものであり入力しなくてもかまいません。あなたはご自分のアカウント情報のどの情報を公開するかをご自分で選択できます。さらにあなたは phpBBソフトウェア からの自動送信メールについて、許可・不許可を選択できます。<br />
 	<br />
 	あなたのパスワードは暗号 （一方向性ハッシュ） 化されているため安全です。しかし複数のサイトで同じパスワードを使用することは望ましくありません。あなたのパスワードは “%1$s” のあなたのアカウントにアクセスする唯一の手段なので大切に管理してください。いかなる状況においても “%1$s” の関係者、phpBB Group または phpBB Group の関連団体があなたのパスワードをあなたに問い合わせるようなことはありません。もしパスワードを忘れるようなことがあればログインページ内の “パスワードを忘れてしまいました” リンクをクリックしてください。移動先のページであなたのユーザー名とメールアドレスを入力し送信が完了し次第、phpBBソフトウェア はあなたのアカウントのための新しいパスワードを発行します。<br />
 	',
@@ -142,6 +140,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> '現在の画像',
 	'CURRENT_PASSWORD'			=> '現在のパスワード',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'パスワード、メールアドレス、ユーザー名を変更するには現在のパスワードを入力する必要があります',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'パスワード、メールアドレス、ユーザー名を変更するには現在のパスワードを入力する必要があります',
 	'CUR_PASSWORD_EMPTY'		=> '現在のパスワード が未入力です',
 	'CUR_PASSWORD_ERROR'		=> '現在のパスワード が正しくありません',
 	'CUSTOM_DATEFORMAT'			=> 'カスタム…',
@@ -186,7 +185,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_DRAFT_TITLE'			=> '下書きの件名が入力されていません',
 	'EXPORT_AS_XML'				=> 'XML 形式',
 	'EXPORT_AS_CSV'				=> 'CSV 形式',
-	'EXPORT_AS_CSV_EXCEL'		=> 'CSV 形式 （ Excel ）',
+	'EXPORT_AS_CSV_EXCEL'		=> 'CSV 形式 (Excel)',
 	'EXPORT_AS_TXT'				=> 'TXT 形式',
 	'EXPORT_AS_MSG'				=> 'MSG 形式',
 	'EXPORT_FOLDER'				=> 'フォルダのエクスポート',
@@ -248,7 +247,7 @@ $lang = array_merge($lang, array(
 	'LINK_REMOTE_AVATAR'		=> '他サイトのアバター画像にリンクする',
 	'LINK_REMOTE_AVATAR_EXPLAIN'=> 'アバター画像の URL を入力してください。リンク経由で表示されます。',
 	'LINK_REMOTE_SIZE'			=> 'アバター画像のサイズ',
-	'LINK_REMOTE_SIZE_EXPLAIN'	=> 'アバター画像の横幅と高さを入力してください。空白（または 0 x 0 ）にした場合、自動で判別されます。',
+	'LINK_REMOTE_SIZE_EXPLAIN'	=> 'アバター画像の横幅と高さを入力してください。空白（または 0 x 0)にした場合、自動で判別されます。',
 	'LOGIN_EXPLAIN_UCP'			=> 'ユーザーCP へ入室するにはログインが必要です',
 	'LOGIN_REDIRECT'			=> 'ログインに成功しました',
 	'LOGOUT_FAILED'				=> 'HTTPリクエスト がセッションと一致しなかったため、ログアウトできませんでした。この症状が頻繁に起こるようなら管理人にこの事をご連絡ください。',
@@ -391,6 +390,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> 'ルールの追加に成功しました',
 	'RULE_ALREADY_DEFINED'				=> 'このルールは既に存在しています',
 	'RULE_DELETED'						=> 'ルールの削除に成功しました',
+	'RULE_LIMIT_REACHED'				=> 'これ以上ルールを追加することはできません',
 	'RULE_NOT_DEFINED'					=> 'ルールが正しく作成されませんでした',
 	'RULE_REMOVED_MESSAGE'				=> 'PMルール によって 1 件のプライベートメッセージを削除しました',
 	'RULE_REMOVED_MESSAGES'				=> 'PMルール によって %d 件のプライベートメッセージを削除しました',
